@@ -15,7 +15,7 @@ Readonly::Scalar my $EMPTY_STR => q{};
 Readonly::Scalar my $LINE_SIZE => 79;
 Readonly::Scalar my $SPACE => q{ };
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 # Constructor.
 sub new {
@@ -327,6 +327,34 @@ __END__
  # Description: File
  # Author.....: skim.cz
 
+=head1 EXAMPLE4
+
+ use strict;
+ use warnings;
+
+ use Encode qw(decode_utf8 encode_utf8);
+ use Indent::Form;
+
+ # Indent object.
+ my $indent = Indent::Form->new;
+
+ # Input data.
+ my $input_ar = [
+         ['Filename', 'foo.bar'],
+         ['Size', '1456kB'],
+         ['Description', 'File'],
+         ['Author', 'skim.cz'],
+ ];
+
+ # Indent.
+ print encode_utf8($indent->indent($input_ar, decode_utf8('|↔| ')))."\n";
+
+ # Output:
+ # |↔|    Filename: foo.bar
+ # |↔|        Size: 1456kB
+ # |↔| Description: File
+ # |↔|      Author: skim.cz
+
 =head1 DEPENDENCIES
 
 L<Class::Utils>,
@@ -386,6 +414,6 @@ L<http://skim.cz>
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
